@@ -1,13 +1,27 @@
 import argparse
 
-from .__init__ import PORT, CACHE_PATH
+from .__init__ import CACHE_PATH, PORT
 
 
 def kill():
+    import os
+    import signal
     import socket
 
     s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    s.sendto(b'#Kill', ('localhost', PORT))
+    s.sendto(b'2Kill', ('localhost', PORT))
+
+    try:
+        tmp_dir = os.environ['TMP'] + '/shellserver'
+        tmp_file = tmp_dir + '/shellserver_pid'
+        with open(tmp_file, 'r') as tmp:
+            pid = int(tmp.read().strip())
+        os.kill(pid, signal.SIGTERM)
+
+        os.remove(tmp_file)
+
+    except OSError:
+        pass
 
 
 def clear():
@@ -16,7 +30,7 @@ def clear():
     try:
         os.remove(CACHE_PATH)
     except FileNotFoundError:
-        pass  # noqa
+        pass
 
 
 def main():
